Home
last modified time | relevance | path

Searched refs:__device__ (Results 1 – 25 of 160) sorted by relevance

1234567

/llvm-project-15.0.7/clang/lib/Headers/
H A D__clang_hip_libdevice_declares.h27 __device__ __attribute__((const)) __device__ float __ocml_copysign_f32(float,
29 __device__ float __ocml_cos_f32(float);
31 __device__ __attribute__((pure)) __device__ float __ocml_cosh_f32(float);
33 __device__ float __ocml_i0_f32(float);
34 __device__ float __ocml_i1_f32(float);
52 __device__ __attribute__((const)) __device__ float __ocml_fmod_f32(float,
61 __device__ float __ocml_j0_f32(float);
62 __device__ float __ocml_j1_f32(float);
237 __device__ double
323 __device__ __attribute__((const))
[all …]
H A D__clang_cuda_intrinsics.h214 inline __device__ unsigned int __activemask() { in __activemask()
237 inline __device__ unsigned int
242 inline __device__ unsigned int
247 inline __device__ unsigned int
292 inline __device__ char2 __ldg(const char2 *ptr) { in __ldg()
303 inline __device__ char4 __ldg(const char4 *ptr) { in __ldg()
313 inline __device__ short2 __ldg(const short2 *ptr) { in __ldg()
331 inline __device__ int2 __ldg(const int2 *ptr) { in __ldg()
339 inline __device__ int4 __ldg(const int4 *ptr) { in __ldg()
394 inline __device__ uint2 __ldg(const uint2 *ptr) { in __ldg()
[all …]
H A D__clang_hip_runtime_wrapper.h22 #define __device__ __attribute__((device)) macro
37 __device__ void __cxa_pure_virtual(void) { in __cxa_pure_virtual()
43 __device__ void __cxa_deleted_virtual(void) { in __cxa_deleted_virtual()
82 extern "C" __device__ void __ockl_dm_dealloc(unsigned long long __addr);
83 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) { in malloc()
86 __attribute__((weak)) inline __device__ void free(void *__ptr) { in free()
91 __device__ void *__hip_malloc(__hip_size_t __size);
92 __device__ void *__hip_free(void *__ptr);
93 __attribute__((weak)) inline __device__ void *malloc(__hip_size_t __size) {
96 __attribute__((weak)) inline __device__ void free(void *__ptr) {
[all …]
H A D__clang_cuda_runtime_wrapper.h246 static inline __device__ void __brkpt(int __c) { __brkpt(); } in __brkpt()
404 __device__ int vprintf(const char *, const char *);
405 __device__ void free(void *) __attribute((nothrow));
418 __device__ static inline void __assert_fail(const char *__message, in __assert_fail()
426 __device__ int printf(const char *, ...);
431 __device__ static inline void free(void *__ptr) { ::free(__ptr); } in free()
432 __device__ static inline void *malloc(size_t __size) { in malloc()
448 __device__ inline __cuda_builtin_blockIdx_t::operator dim3() const { in dim3()
456 __device__ inline __cuda_builtin_blockDim_t::operator dim3() const { in dim3()
464 __device__ inline __cuda_builtin_gridDim_t::operator dim3() const { in dim3()
[all …]
/llvm-project-15.0.7/clang/test/SemaCUDA/
H A Ddevice-var-init.cu27 __device__ T d_t_i = {2};
34 __device__ EC d_ec_i(3);
62 __device__ UC d_uc;
69 __device__ UD d_ud;
76 __device__ ECI d_eci;
83 __device__ NEC d_nec;
90 __device__ NED d_ned;
97 __device__ NCV d_ncv;
104 __device__ VD d_vd;
111 __device__ NCF d_ncf;
[all …]
H A Dcall-host-fn-from-device.cu23 __host__ __device__ void hd() { host_fn(); } in hd()
30 __host__ __device__ void hd3();
53 __host__ __device__ void T::hd3() { in hd3()
62 __host__ __device__ void hd() { host_fn(); } in hd()
67 __device__ void device_fn() { hd3<int>(); } in device_fn()
72 __host__ __device__ void local_var() { in local_var()
92 __host__ __device__ void hd_member_fn() { in hd_member_fn()
99 __host__ __device__ void h_member_fn() { in h_member_fn()
105 __host__ __device__ void fn_ptr() { in fn_ptr()
115 __host__ __device__ void unaryOp() { in unaryOp()
[all …]
H A Dfunction-overload.cu60 __device__ int hdd() { return 0; } in hdd()
134 __device__ void devicef() { in devicef()
239 __host__ __device__ ~d_hd() {} in ~d_hd()
449 __device__
465 __device__ void *b = new int;
558 __device__ a(short);
560 __device__ operator int() const;
576 __device__ operator int() const;
590 __host__ __device__ a(short);
592 __device__ operator int() const;
[all …]
H A Dcall-device-fn-from-host.cu11 __device__ void device_fn() {} in device_fn()
15 __device__ S() {} in S()
17 __device__ ~S() { device_fn(); } in ~S()
30 __host__ __device__ void hd3();
32 __device__ void d() {} in d()
36 __host__ __device__ void T::hd3() { in hd3()
51 __host__ __device__ void local_var() { in local_var()
66 __host__ __device__ void hd_member_fn() { in hd_member_fn()
73 __host__ __device__ void h_member_fn() { in h_member_fn()
79 __host__ __device__ void fn_ptr() { in fn_ptr()
[all …]
H A Dconst-var.cu24 __device__ const int *const B::p2 = &a;
26 __device__ void f() { in f()
46 __device__ void f() { in f()
90 __device__ int d = 1;
93 __device__ static int *const p1;
94 __device__ static int *const p2;
101 __device__ int *const B::p1 = &a;
103 __device__ int *const B::p2 = &b;
105 __device__ int *const B::p3 = &c;
107 __device__ int *const B::p4 = &d;
[all …]
H A Dimplicit-device-lambda.cu8 __device__ void device_fn() { in device_fn()
12 auto f2 = [&] __device__ {}; in device_fn()
18 auto f4 = [&] __host__ __device__ {}; in device_fn()
26 auto g2 = [&]() __device__ {}; in device_fn()
39 auto h2 = [&] __device__ () {}; in device_fn()
54 auto f2 = [&] __device__ {}; in kernel_fn()
60 auto f4 = [&] __host__ __device__ {}; in kernel_fn()
71 auto f2 = [&] __device__ {}; in host_fn()
81 __host__ __device__ void hd_fn() { in hd_fn()
85 auto f2 = [&] __device__ {}; in hd_fn()
[all …]
H A Dusual-deallocators.cu12 extern __device__ void dev_fn();
13 extern __host__ __device__ void hd_fn();
17 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
23 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
28 __device__ void operator delete(void *) = delete;
39 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
49 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
56 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
68 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
74 __host__ __device__ void test_hd(void *p) { in test_hd()
[all …]
H A Dunion-init.cu7 __device__ A() { a = 1; } in A()
8 __device__ ~A() { a = 2; } in ~A()
14 __device__ B() {} in B()
15 __device__ ~B() {} in ~B()
21 __device__ C() { a.a = 3; } in C()
22 __device__ ~C() {} in ~C()
28 __device__ D() { } in D()
32 __device__ B b;
33 __device__ C c;
35 __device__ D d;
[all …]
H A Dfunction-template-overload.cu13 template <typename T> __device__ DType overload_h_d(T a) { return DType(); } in overload_h_d()
22 template __device__ DType overload_h_d(int a); // OK. instantiates D
30 template <> __device__ DType overload_h_d(long a); // OK. instantiates D
39 template <typename T> __device__ HDType overload_hd(T a);
41 __device__ HDType overload_hd(int a); // OK.
52 template <typename T> __host__ __device__ T overload_h(T a);
54 template <typename T> __device__ T overload_h(T a); // OK. D can overload H.
66 template __host__ __device__ int overload_ce_implicit_hd(int a);
68 template <> __host__ __device__ long overload_ce_implicit_hd(long a);
70 template <> __host__ __device__ constexpr long overload_ce_implicit_hd(long a);
[all …]
H A Doverloaded-delete.cu10 __device__ static void operator delete(void*, size_t) {} in operator delete()
13 __host__ __device__ void test(S* s) { in test()
21 __host__ __device__ void test_default_global_delete_hd(int *ptr) { in test_default_global_delete_hd()
26 __device__ void test_default_global_delete(int *ptr) { in test_default_global_delete()
36 __device__ void operator delete(void *ptr);
38 __host__ __device__ void test_partial_global_delete_hd(int *ptr) { in test_partial_global_delete_hd()
43 __device__ void test_partial_global_delete(int *ptr) { in test_partial_global_delete()
55 __device__ void operator delete(void *ptr) {} in operator delete()
57 __host__ __device__ void test_overloaded_global_delete_hd(int *ptr) { in test_overloaded_global_delete_hd()
62 __device__ void test_overloaded_global_delete(int *ptr) { in test_overloaded_global_delete()
H A Dbad-attributes.cu14 __device__ int a1;
15 __device__ void a2();
28 __device__ __host__ void z1();
29 __device__ __constant__ int z2;
30 __device__ __shared__ int z3;
31 __device__ __global__ void z4(); // expected-error {{attributes are not compatible}}
34 __host__ __device__ void z5();
38 __constant__ __device__ int z7;
42 __shared__ __device__ int z9;
48 __global__ __device__ void z11(); // expected-error {{attributes are not compatible}}
[all …]
H A Dconstexpr-var.cu18 __device__ static constexpr const int *const p2 = &a;
25 __device__ void f() { in f()
44 __device__ void f() { in f()
91 __device__ int d = 1;
94 __device__ static constexpr int *const p1 = &a;
96 __device__ static constexpr int *const p2 = &b;
98 __device__ static constexpr int *const p3 = &c;
100 __device__ static constexpr int *const p4 = &d;
101 __device__ static constexpr int *const p5 = &e;
102 __device__ static constexpr texture<float, 2, ElementType> *const p6 = &tex;
[all …]
H A Dimplicit-member-target.cu27 __device__ void devicefoo() { in devicefoo()
35 __device__ A2_with_device_ctor() {} in A2_with_device_ctor()
49 __device__ void devicefoo2() { in devicefoo2()
58 __device__ A3_with_device_ctors(const A3_with_device_ctors&) {} in A3_with_device_ctors()
93 __device__ void devicefoo4() { in devicefoo4()
115 __device__ void devicefoo5(B5_copy_ctor_constness& b_arg) { in devicefoo5()
124 __device__ A6_with_device_ctor() {} in A6_with_device_ctor()
135 __device__ void devicefoo6() { in devicefoo6()
144 __device__ A7_with_copy_assign& operator=(const A7_with_copy_assign&) {} in operator =()
174 __device__ A8_with_move_assign& operator=(A8_with_move_assign&&) {} in operator =()
[all …]
/llvm-project-15.0.7/clang/test/CodeGenCUDA/Inputs/
H A Dcuda-initializers.h14 __device__ EC() {} // -- allowed in EC()
36 __device__ UC();
42 __device__ ~UD();
48 __device__ ECI() : eci(1) {} in ECI()
54 __device__ NEC() { nec = 1; } in NEC()
60 __device__ ~NED() { ned = 1; } in ~NED()
66 __device__ virtual void vm() {} in vm()
71 __device__ virtual ~VD() {} in ~VD()
75 __device__ int f();
115 __device__ EC_I_EC() : EC() {} in EC_I_EC()
[all …]
/llvm-project-15.0.7/clang/test/SemaCUDA/Inputs/
H A Dcuda-initializers.h14 __device__ EC() {} // -- allowed in EC()
36 __device__ UC();
42 __device__ ~UD();
48 __device__ ECI() : eci(1) {} in ECI()
54 __device__ NEC() { nec = 1; } in NEC()
60 __device__ ~NED() { ned = 1; } in ~NED()
66 __device__ virtual void vm() {} in vm()
71 __device__ virtual ~VD() {} in ~VD()
75 __device__ int f();
115 __device__ EC_I_EC() : EC() {} in EC_I_EC()
[all …]
/llvm-project-15.0.7/clang/test/CodeGenCUDA/
H A Dusual-deallocators.cu12 extern "C" __device__ void dev_fn();
13 extern "C" __host__ __device__ void hd_fn();
30 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
35 __device__ void operator delete(void *, __SIZE_TYPE__) { dev_fn(); }; in operator delete()
40 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
45 __device__ void operator delete(void *, __SIZE_TYPE__) { dev_fn(); }; in operator delete()
50 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
57 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
69 __device__ void operator delete(void *) { dev_fn(); }; in operator delete()
75 __host__ __device__ void test_hd(void *p) { in test_hd()
[all …]
H A Ddevice-var-init.cu22 __device__ int d_v;
32 __device__ int d_v_i = 1;
42 __device__ int foo() { in foo()
47 __device__ T d_t;
57 __device__ T d_t_i = {2};
65 __device__ EC d_ec;
76 __device__ ED d_ed;
86 __device__ ECD d_ecd;
97 __device__ ETC d_etc;
107 __device__ NCFS d_ncfs;
[all …]
H A Dhost-used-device-var.cu19 __device__ int v1;
27 static __device__ int v3;
32 __device__ int u1;
39 static __device__ int u3;
43 static __device__ int u4;
47 __device__ __attribute__((used)) int u5;
51 extern __device__ int ext_var;
54 __device__ inline int inline_var;
60 __device__ T add_func (T x, T y) in add_func()
106 __host__ __device__ void fun2() { in fun2()
[all …]
H A Dstatic-device-var-no-rdc.cu30 static __device__ int x;
35 static __device__ int x2;
39 static __device__ int x3;
43 static __device__ int x4;
49 static __device__ int x5;
79 static __device__ int w;
85 static __device__ int u;
87 inline __device__ void devfun(const int ** b) { in devfun()
96 const static __device__ int local_static_device = 43; in kernel()
111 __host__ __device__ void hdf(int *a) { in hdf()
/llvm-project-15.0.7/clang/test/Headers/Inputs/include/
H A Dcuda.h8 #define __device__ __attribute__((device)) macro
23 __device__ void *operator new(__SIZE_TYPE__, void *p) { return p; } in new()
24 __device__ void *operator new[](__SIZE_TYPE__, void *p) { return p; }
30 __host__ __device__ char2(char x = 0, char y = 0) : x(x), y(y) {} in x()
39 __host__ __device__ uchar2(unsigned char x = 0, unsigned char y = 0) : x(x), y(y) {} in x()
48 __host__ __device__ short2(short x = 0, short y = 0) : x(x), y(y) {} in x()
66 __host__ __device__ int2(int x = 0, int y = 0) : x(x), y(y) {} in x()
75 __host__ __device__ uint2(unsigned x = 0, unsigned y = 0) : x(x), y(y) {} in x()
88 __host__ __device__ longlong2(long long x = 0, long long y = 0) : x(x), y(y) {} in x()
106 __host__ __device__ float2(float x = 0, float y = 0) : x(x), y(y) {} in x()
[all …]
/llvm-project-15.0.7/clang/test/Headers/Inputs/include/crt/
H A Dmath_functions.hpp3 __device__ int __isinff(float);
4 __device__ int __isinf(double);
5 __device__ int __finitef(float);
6 __device__ int __isfinited(double);
7 __device__ int __isnanf(float);
8 __device__ int __isnan(double);
9 __device__ int __signbitf(float);
10 __device__ int __signbitd(double);
11 __device__ double max(double, double);
12 __device__ float max(float, float);

1234567